# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class EntityGroupInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'EntityGroupId',
        'created_time': 'int',
        'type': 'str',
        'name': 'str',
        'owner_id': 'EntityId',
        'additional_info': 'JsonNode',
        'configuration': 'JsonNode',
        'version': 'int',
        'owner_ids': 'list[EntityId]',
        'edge_group_all': 'bool',
        'group_all': 'bool',
        'tenant_id': 'TenantId'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'type': 'type',
        'name': 'name',
        'owner_id': 'ownerId',
        'additional_info': 'additionalInfo',
        'configuration': 'configuration',
        'version': 'version',
        'owner_ids': 'ownerIds',
        'edge_group_all': 'edgeGroupAll',
        'group_all': 'groupAll',
        'tenant_id': 'tenantId'
    }

    def __init__(self, id=None, created_time=None, type=None, name=None, owner_id=None, additional_info=None, configuration=None, version=None, owner_ids=None, edge_group_all=None, group_all=None, tenant_id=None):  # noqa: E501
        """EntityGroupInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._type = None
        self._name = None
        self._owner_id = None
        self._additional_info = None
        self._configuration = None
        self._version = None
        self._owner_ids = None
        self._edge_group_all = None
        self._group_all = None
        self._tenant_id = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        self.type = type
        self.name = name
        if owner_id is not None:
            self.owner_id = owner_id
        if additional_info is not None:
            self.additional_info = additional_info
        if configuration is not None:
            self.configuration = configuration
        if version is not None:
            self.version = version
        self.owner_ids = owner_ids
        if edge_group_all is not None:
            self.edge_group_all = edge_group_all
        if group_all is not None:
            self.group_all = group_all
        if tenant_id is not None:
            self.tenant_id = tenant_id

    @property
    def id(self):
        """Gets the id of this EntityGroupInfo.  # noqa: E501


        :return: The id of this EntityGroupInfo.  # noqa: E501
        :rtype: EntityGroupId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EntityGroupInfo.


        :param id: The id of this EntityGroupInfo.  # noqa: E501
        :type: EntityGroupId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this EntityGroupInfo.  # noqa: E501

        Timestamp of the entity group creation, in milliseconds  # noqa: E501

        :return: The created_time of this EntityGroupInfo.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this EntityGroupInfo.

        Timestamp of the entity group creation, in milliseconds  # noqa: E501

        :param created_time: The created_time of this EntityGroupInfo.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def type(self):
        """Gets the type of this EntityGroupInfo.  # noqa: E501


        :return: The type of this EntityGroupInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EntityGroupInfo.


        :param type: The type of this EntityGroupInfo.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["CUSTOMER", "ASSET", "DEVICE", "USER", "ENTITY_VIEW", "DASHBOARD", "EDGE"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def name(self):
        """Gets the name of this EntityGroupInfo.  # noqa: E501

        Name of the entity group  # noqa: E501

        :return: The name of this EntityGroupInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EntityGroupInfo.

        Name of the entity group  # noqa: E501

        :param name: The name of this EntityGroupInfo.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def owner_id(self):
        """Gets the owner_id of this EntityGroupInfo.  # noqa: E501


        :return: The owner_id of this EntityGroupInfo.  # noqa: E501
        :rtype: EntityId
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this EntityGroupInfo.


        :param owner_id: The owner_id of this EntityGroupInfo.  # noqa: E501
        :type: EntityId
        """

        self._owner_id = owner_id

    @property
    def additional_info(self):
        """Gets the additional_info of this EntityGroupInfo.  # noqa: E501


        :return: The additional_info of this EntityGroupInfo.  # noqa: E501
        :rtype: JsonNode
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this EntityGroupInfo.


        :param additional_info: The additional_info of this EntityGroupInfo.  # noqa: E501
        :type: JsonNode
        """

        self._additional_info = additional_info

    @property
    def configuration(self):
        """Gets the configuration of this EntityGroupInfo.  # noqa: E501


        :return: The configuration of this EntityGroupInfo.  # noqa: E501
        :rtype: JsonNode
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this EntityGroupInfo.


        :param configuration: The configuration of this EntityGroupInfo.  # noqa: E501
        :type: JsonNode
        """

        self._configuration = configuration

    @property
    def version(self):
        """Gets the version of this EntityGroupInfo.  # noqa: E501


        :return: The version of this EntityGroupInfo.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this EntityGroupInfo.


        :param version: The version of this EntityGroupInfo.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def owner_ids(self):
        """Gets the owner_ids of this EntityGroupInfo.  # noqa: E501

        List of the entity group owners.  # noqa: E501

        :return: The owner_ids of this EntityGroupInfo.  # noqa: E501
        :rtype: list[EntityId]
        """
        return self._owner_ids

    @owner_ids.setter
    def owner_ids(self, owner_ids):
        """Sets the owner_ids of this EntityGroupInfo.

        List of the entity group owners.  # noqa: E501

        :param owner_ids: The owner_ids of this EntityGroupInfo.  # noqa: E501
        :type: list[EntityId]
        """
        if owner_ids is None:
            raise ValueError("Invalid value for `owner_ids`, must not be `None`")  # noqa: E501

        self._owner_ids = owner_ids

    @property
    def edge_group_all(self):
        """Gets the edge_group_all of this EntityGroupInfo.  # noqa: E501

        Indicates special edge group 'All' that contains all entities and can't be deleted.  # noqa: E501

        :return: The edge_group_all of this EntityGroupInfo.  # noqa: E501
        :rtype: bool
        """
        return self._edge_group_all

    @edge_group_all.setter
    def edge_group_all(self, edge_group_all):
        """Sets the edge_group_all of this EntityGroupInfo.

        Indicates special edge group 'All' that contains all entities and can't be deleted.  # noqa: E501

        :param edge_group_all: The edge_group_all of this EntityGroupInfo.  # noqa: E501
        :type: bool
        """

        self._edge_group_all = edge_group_all

    @property
    def group_all(self):
        """Gets the group_all of this EntityGroupInfo.  # noqa: E501

        Indicates special group 'All' that contains all entities and can't be deleted.  # noqa: E501

        :return: The group_all of this EntityGroupInfo.  # noqa: E501
        :rtype: bool
        """
        return self._group_all

    @group_all.setter
    def group_all(self, group_all):
        """Sets the group_all of this EntityGroupInfo.

        Indicates special group 'All' that contains all entities and can't be deleted.  # noqa: E501

        :param group_all: The group_all of this EntityGroupInfo.  # noqa: E501
        :type: bool
        """

        self._group_all = group_all

    @property
    def tenant_id(self):
        """Gets the tenant_id of this EntityGroupInfo.  # noqa: E501


        :return: The tenant_id of this EntityGroupInfo.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this EntityGroupInfo.


        :param tenant_id: The tenant_id of this EntityGroupInfo.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EntityGroupInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntityGroupInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
