# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class DebugSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'failures_enabled': 'object',
        'all_enabled': 'object',
        'all_enabled_until': 'object'
    }

    attribute_map = {
        'failures_enabled': 'failuresEnabled',
        'all_enabled': 'allEnabled',
        'all_enabled_until': 'allEnabledUntil'
    }

    def __init__(self, failures_enabled=None, all_enabled=None, all_enabled_until=None):  # noqa: E501
        """DebugSettings - a model defined in Swagger"""  # noqa: E501
        self._failures_enabled = None
        self._all_enabled = None
        self._all_enabled_until = None
        self.discriminator = None
        if failures_enabled is not None:
            self.failures_enabled = failures_enabled
        if all_enabled is not None:
            self.all_enabled = all_enabled
        if all_enabled_until is not None:
            self.all_enabled_until = all_enabled_until

    @property
    def failures_enabled(self):
        """Gets the failures_enabled of this DebugSettings.  # noqa: E501

        Debug failures.   # noqa: E501

        :return: The failures_enabled of this DebugSettings.  # noqa: E501
        :rtype: object
        """
        return self._failures_enabled

    @failures_enabled.setter
    def failures_enabled(self, failures_enabled):
        """Sets the failures_enabled of this DebugSettings.

        Debug failures.   # noqa: E501

        :param failures_enabled: The failures_enabled of this DebugSettings.  # noqa: E501
        :type: object
        """

        self._failures_enabled = failures_enabled

    @property
    def all_enabled(self):
        """Gets the all_enabled of this DebugSettings.  # noqa: E501

        Debug All. Used as a trigger for updating debugAllUntil.  # noqa: E501

        :return: The all_enabled of this DebugSettings.  # noqa: E501
        :rtype: object
        """
        return self._all_enabled

    @all_enabled.setter
    def all_enabled(self, all_enabled):
        """Sets the all_enabled of this DebugSettings.

        Debug All. Used as a trigger for updating debugAllUntil.  # noqa: E501

        :param all_enabled: The all_enabled of this DebugSettings.  # noqa: E501
        :type: object
        """

        self._all_enabled = all_enabled

    @property
    def all_enabled_until(self):
        """Gets the all_enabled_until of this DebugSettings.  # noqa: E501

        Timestamp of the end time for the processing debug events.  # noqa: E501

        :return: The all_enabled_until of this DebugSettings.  # noqa: E501
        :rtype: object
        """
        return self._all_enabled_until

    @all_enabled_until.setter
    def all_enabled_until(self, all_enabled_until):
        """Sets the all_enabled_until of this DebugSettings.

        Timestamp of the end time for the processing debug events.  # noqa: E501

        :param all_enabled_until: The all_enabled_until of this DebugSettings.  # noqa: E501
        :type: object
        """

        self._all_enabled_until = all_enabled_until

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DebugSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DebugSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
