# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class MobileApp(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'MobileAppId',
        'created_time': 'int',
        'tenant_id': 'TenantId',
        'pkg_name': 'str',
        'app_secret': 'str',
        'oauth2_enabled': 'bool',
        'name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_time': 'createdTime',
        'tenant_id': 'tenantId',
        'pkg_name': 'pkgName',
        'app_secret': 'appSecret',
        'oauth2_enabled': 'oauth2Enabled',
        'name': 'name'
    }

    def __init__(self, id=None, created_time=None, tenant_id=None, pkg_name=None, app_secret=None, oauth2_enabled=None, name=None):  # noqa: E501
        """MobileApp - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_time = None
        self._tenant_id = None
        self._pkg_name = None
        self._app_secret = None
        self._oauth2_enabled = None
        self._name = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if tenant_id is not None:
            self.tenant_id = tenant_id
        self.pkg_name = pkg_name
        self.app_secret = app_secret
        if oauth2_enabled is not None:
            self.oauth2_enabled = oauth2_enabled
        if name is not None:
            self.name = name

    @property
    def id(self):
        """Gets the id of this MobileApp.  # noqa: E501


        :return: The id of this MobileApp.  # noqa: E501
        :rtype: MobileAppId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MobileApp.


        :param id: The id of this MobileApp.  # noqa: E501
        :type: MobileAppId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this MobileApp.  # noqa: E501


        :return: The created_time of this MobileApp.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this MobileApp.


        :param created_time: The created_time of this MobileApp.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def tenant_id(self):
        """Gets the tenant_id of this MobileApp.  # noqa: E501


        :return: The tenant_id of this MobileApp.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this MobileApp.


        :param tenant_id: The tenant_id of this MobileApp.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    @property
    def pkg_name(self):
        """Gets the pkg_name of this MobileApp.  # noqa: E501

        Application package name. Cannot be empty  # noqa: E501

        :return: The pkg_name of this MobileApp.  # noqa: E501
        :rtype: str
        """
        return self._pkg_name

    @pkg_name.setter
    def pkg_name(self, pkg_name):
        """Sets the pkg_name of this MobileApp.

        Application package name. Cannot be empty  # noqa: E501

        :param pkg_name: The pkg_name of this MobileApp.  # noqa: E501
        :type: str
        """
        if pkg_name is None:
            raise ValueError("Invalid value for `pkg_name`, must not be `None`")  # noqa: E501

        self._pkg_name = pkg_name

    @property
    def app_secret(self):
        """Gets the app_secret of this MobileApp.  # noqa: E501

        Application secret. The length must be at least 16 characters  # noqa: E501

        :return: The app_secret of this MobileApp.  # noqa: E501
        :rtype: str
        """
        return self._app_secret

    @app_secret.setter
    def app_secret(self, app_secret):
        """Sets the app_secret of this MobileApp.

        Application secret. The length must be at least 16 characters  # noqa: E501

        :param app_secret: The app_secret of this MobileApp.  # noqa: E501
        :type: str
        """
        if app_secret is None:
            raise ValueError("Invalid value for `app_secret`, must not be `None`")  # noqa: E501

        self._app_secret = app_secret

    @property
    def oauth2_enabled(self):
        """Gets the oauth2_enabled of this MobileApp.  # noqa: E501

        Whether OAuth2 settings are enabled or not  # noqa: E501

        :return: The oauth2_enabled of this MobileApp.  # noqa: E501
        :rtype: bool
        """
        return self._oauth2_enabled

    @oauth2_enabled.setter
    def oauth2_enabled(self, oauth2_enabled):
        """Sets the oauth2_enabled of this MobileApp.

        Whether OAuth2 settings are enabled or not  # noqa: E501

        :param oauth2_enabled: The oauth2_enabled of this MobileApp.  # noqa: E501
        :type: bool
        """

        self._oauth2_enabled = oauth2_enabled

    @property
    def name(self):
        """Gets the name of this MobileApp.  # noqa: E501

        Mobile app package name  # noqa: E501

        :return: The name of this MobileApp.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MobileApp.

        Mobile app package name  # noqa: E501

        :param name: The name of this MobileApp.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MobileApp, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MobileApp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
