# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class ConverterLibraryControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_downlink_converter(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink converter (getDownlinkConverter)  # noqa: E501

        Returns downlink converter body for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_converter(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_downlink_converter_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_downlink_converter_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_downlink_converter_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink converter (getDownlinkConverter)  # noqa: E501

        Returns downlink converter body for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_converter_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_downlink_converter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_downlink_converter`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_downlink_converter`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_downlink_converter`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/downlink', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_downlink_converter_metadata(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink converter metadata (getDownlinkConverterMetadata)  # noqa: E501

        Returns downlink converter metadata for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_converter_metadata(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_downlink_converter_metadata_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_downlink_converter_metadata_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_downlink_converter_metadata_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink converter metadata (getDownlinkConverterMetadata)  # noqa: E501

        Returns downlink converter metadata for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_converter_metadata_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_downlink_converter_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_downlink_converter_metadata`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_downlink_converter_metadata`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_downlink_converter_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/downlink/metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_downlink_payload(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink payload (getDownlinkPayload)  # noqa: E501

        Returns payload example for the downlink converter for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_payload(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_downlink_payload_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_downlink_payload_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_downlink_payload_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get downlink payload (getDownlinkPayload)  # noqa: E501

        Returns payload example for the downlink converter for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_downlink_payload_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_downlink_payload" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_downlink_payload`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_downlink_payload`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_downlink_payload`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/downlink/payload', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_uplink_converter(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink converter (getUplinkConverter)  # noqa: E501

        Returns uplink converter body for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_converter(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_uplink_converter_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_uplink_converter_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_uplink_converter_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink converter (getUplinkConverter)  # noqa: E501

        Returns uplink converter body for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_converter_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_uplink_converter" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_uplink_converter`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_uplink_converter`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_uplink_converter`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/uplink', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_uplink_converter_metadata(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink converter metadata (getUplinkConverterMetadata)  # noqa: E501

        Returns uplink converter metadata for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_converter_metadata(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_uplink_converter_metadata_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_uplink_converter_metadata_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_uplink_converter_metadata_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink converter metadata (getUplinkConverterMetadata)  # noqa: E501

        Returns uplink converter metadata for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_converter_metadata_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_uplink_converter_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_uplink_converter_metadata`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_uplink_converter_metadata`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_uplink_converter_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/uplink/metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_uplink_payload(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink payload (getUplinkPayload)  # noqa: E501

        Returns payload example for the uplink converter for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_payload(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_uplink_payload_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
        else:
            (data) = self.get_uplink_payload_with_http_info(integration_type, vendor_name, model, **kwargs)  # noqa: E501
            return data

    def get_uplink_payload_with_http_info(self, integration_type, vendor_name, model, **kwargs):  # noqa: E501
        """Get uplink payload (getUplinkPayload)  # noqa: E501

        Returns payload example for the uplink converter for the vendor, integration type and model  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_uplink_payload_with_http_info(integration_type, vendor_name, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str model: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'model']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_uplink_payload" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_uplink_payload`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_uplink_payload`")  # noqa: E501
        # verify the required parameter 'model' is set
        if ('model' not in params or
                params['model'] is None):
            raise ValueError("Missing the required parameter `model` when calling `get_uplink_payload`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501
        if 'model' in params:
            path_params['model'] = params['model']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/{model}/uplink/payload', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_vendor_models(self, integration_type, vendor_name, **kwargs):  # noqa: E501
        """Get vendor models (getVendorModels)  # noqa: E501

        Returns a list of models for the vendor, integration type and converter type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vendor_models(integration_type, vendor_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str converter_type:
        :return: list[Model]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_vendor_models_with_http_info(integration_type, vendor_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_vendor_models_with_http_info(integration_type, vendor_name, **kwargs)  # noqa: E501
            return data

    def get_vendor_models_with_http_info(self, integration_type, vendor_name, **kwargs):  # noqa: E501
        """Get vendor models (getVendorModels)  # noqa: E501

        Returns a list of models for the vendor, integration type and converter type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vendor_models_with_http_info(integration_type, vendor_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :param str vendor_name: (required)
        :param str converter_type:
        :return: list[Model]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type', 'vendor_name', 'converter_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_vendor_models" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_vendor_models`")  # noqa: E501
        # verify the required parameter 'vendor_name' is set
        if ('vendor_name' not in params or
                params['vendor_name'] is None):
            raise ValueError("Missing the required parameter `vendor_name` when calling `get_vendor_models`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501
        if 'vendor_name' in params:
            path_params['vendorName'] = params['vendor_name']  # noqa: E501

        query_params = []
        if 'converter_type' in params:
            query_params.append(('converterType', params['converter_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/{vendorName}/models{?converterType}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Model]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_vendors(self, integration_type, **kwargs):  # noqa: E501
        """Get vendors (getVendors)  # noqa: E501

        Returns a list of vendors for the integration type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vendors(integration_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :return: list[Vendor]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_vendors_with_http_info(integration_type, **kwargs)  # noqa: E501
        else:
            (data) = self.get_vendors_with_http_info(integration_type, **kwargs)  # noqa: E501
            return data

    def get_vendors_with_http_info(self, integration_type, **kwargs):  # noqa: E501
        """Get vendors (getVendors)  # noqa: E501

        Returns a list of vendors for the integration type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vendors_with_http_info(integration_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str integration_type: (required)
        :return: list[Vendor]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_vendors" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_type' is set
        if ('integration_type' not in params or
                params['integration_type'] is None):
            raise ValueError("Missing the required parameter `integration_type` when calling `get_vendors`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_type' in params:
            path_params['integrationType'] = params['integration_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/converter/library/{integrationType}/vendors', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Vendor]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
