# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class MobileAppVersionInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'min_version': 'str',
        'min_version_release_notes': 'str',
        'latest_version': 'str',
        'latest_version_release_notes': 'str'
    }

    attribute_map = {
        'min_version': 'minVersion',
        'min_version_release_notes': 'minVersionReleaseNotes',
        'latest_version': 'latestVersion',
        'latest_version_release_notes': 'latestVersionReleaseNotes'
    }

    def __init__(self, min_version=None, min_version_release_notes=None, latest_version=None, latest_version_release_notes=None):  # noqa: E501
        """MobileAppVersionInfo - a model defined in Swagger"""  # noqa: E501
        self._min_version = None
        self._min_version_release_notes = None
        self._latest_version = None
        self._latest_version_release_notes = None
        self.discriminator = None
        if min_version is not None:
            self.min_version = min_version
        if min_version_release_notes is not None:
            self.min_version_release_notes = min_version_release_notes
        if latest_version is not None:
            self.latest_version = latest_version
        if latest_version_release_notes is not None:
            self.latest_version_release_notes = latest_version_release_notes

    @property
    def min_version(self):
        """Gets the min_version of this MobileAppVersionInfo.  # noqa: E501

        Minimum supported version  # noqa: E501

        :return: The min_version of this MobileAppVersionInfo.  # noqa: E501
        :rtype: object
        """
        return self._min_version

    @min_version.setter
    def min_version(self, min_version):
        """Sets the min_version of this MobileAppVersionInfo.

        Minimum supported version  # noqa: E501

        :param min_version: The min_version of this MobileAppVersionInfo.  # noqa: E501
        :type: object
        """

        self._min_version = min_version

    @property
    def min_version_release_notes(self):
        """Gets the min_version_release_notes of this MobileAppVersionInfo.  # noqa: E501

        Release notes of minimum supported version  # noqa: E501

        :return: The min_version_release_notes of this MobileAppVersionInfo.  # noqa: E501
        :rtype: object
        """
        return self._min_version_release_notes

    @min_version_release_notes.setter
    def min_version_release_notes(self, min_version_release_notes):
        """Sets the min_version_release_notes of this MobileAppVersionInfo.

        Release notes of minimum supported version  # noqa: E501

        :param min_version_release_notes: The min_version_release_notes of this MobileAppVersionInfo.  # noqa: E501
        :type: object
        """

        self._min_version_release_notes = min_version_release_notes

    @property
    def latest_version(self):
        """Gets the latest_version of this MobileAppVersionInfo.  # noqa: E501

        Latest supported version  # noqa: E501

        :return: The latest_version of this MobileAppVersionInfo.  # noqa: E501
        :rtype: object
        """
        return self._latest_version

    @latest_version.setter
    def latest_version(self, latest_version):
        """Sets the latest_version of this MobileAppVersionInfo.

        Latest supported version  # noqa: E501

        :param latest_version: The latest_version of this MobileAppVersionInfo.  # noqa: E501
        :type: object
        """

        self._latest_version = latest_version

    @property
    def latest_version_release_notes(self):
        """Gets the latest_version_release_notes of this MobileAppVersionInfo.  # noqa: E501

        Release notes of latest supported version  # noqa: E501

        :return: The latest_version_release_notes of this MobileAppVersionInfo.  # noqa: E501
        :rtype: object
        """
        return self._latest_version_release_notes

    @latest_version_release_notes.setter
    def latest_version_release_notes(self, latest_version_release_notes):
        """Sets the latest_version_release_notes of this MobileAppVersionInfo.

        Release notes of latest supported version  # noqa: E501

        :param latest_version_release_notes: The latest_version_release_notes of this MobileAppVersionInfo.  # noqa: E501
        :type: object
        """

        self._latest_version_release_notes = latest_version_release_notes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MobileAppVersionInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MobileAppVersionInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
