# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.9.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2025. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class UserMobileInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user': 'User',
        'store_info': 'StoreInfo',
        'version_info': 'MobileAppVersionInfo',
        'home_dashboard_info': 'HomeDashboardInfo',
        'pages': 'JsonNode'
    }

    attribute_map = {
        'user': 'user',
        'store_info': 'storeInfo',
        'version_info': 'versionInfo',
        'home_dashboard_info': 'homeDashboardInfo',
        'pages': 'pages'
    }

    def __init__(self, user=None, store_info=None, version_info=None, home_dashboard_info=None, pages=None):  # noqa: E501
        """UserMobileInfo - a model defined in Swagger"""  # noqa: E501
        self._user = None
        self._store_info = None
        self._version_info = None
        self._home_dashboard_info = None
        self._pages = None
        self.discriminator = None
        if user is not None:
            self.user = user
        if store_info is not None:
            self.store_info = store_info
        if version_info is not None:
            self.version_info = version_info
        if home_dashboard_info is not None:
            self.home_dashboard_info = home_dashboard_info
        if pages is not None:
            self.pages = pages

    @property
    def user(self):
        """Gets the user of this UserMobileInfo.  # noqa: E501


        :return: The user of this UserMobileInfo.  # noqa: E501
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this UserMobileInfo.


        :param user: The user of this UserMobileInfo.  # noqa: E501
        :type: User
        """

        self._user = user

    @property
    def store_info(self):
        """Gets the store_info of this UserMobileInfo.  # noqa: E501


        :return: The store_info of this UserMobileInfo.  # noqa: E501
        :rtype: StoreInfo
        """
        return self._store_info

    @store_info.setter
    def store_info(self, store_info):
        """Sets the store_info of this UserMobileInfo.


        :param store_info: The store_info of this UserMobileInfo.  # noqa: E501
        :type: StoreInfo
        """

        self._store_info = store_info

    @property
    def version_info(self):
        """Gets the version_info of this UserMobileInfo.  # noqa: E501


        :return: The version_info of this UserMobileInfo.  # noqa: E501
        :rtype: MobileAppVersionInfo
        """
        return self._version_info

    @version_info.setter
    def version_info(self, version_info):
        """Sets the version_info of this UserMobileInfo.


        :param version_info: The version_info of this UserMobileInfo.  # noqa: E501
        :type: MobileAppVersionInfo
        """

        self._version_info = version_info

    @property
    def home_dashboard_info(self):
        """Gets the home_dashboard_info of this UserMobileInfo.  # noqa: E501


        :return: The home_dashboard_info of this UserMobileInfo.  # noqa: E501
        :rtype: HomeDashboardInfo
        """
        return self._home_dashboard_info

    @home_dashboard_info.setter
    def home_dashboard_info(self, home_dashboard_info):
        """Sets the home_dashboard_info of this UserMobileInfo.


        :param home_dashboard_info: The home_dashboard_info of this UserMobileInfo.  # noqa: E501
        :type: HomeDashboardInfo
        """

        self._home_dashboard_info = home_dashboard_info

    @property
    def pages(self):
        """Gets the pages of this UserMobileInfo.  # noqa: E501


        :return: The pages of this UserMobileInfo.  # noqa: E501
        :rtype: JsonNode
        """
        return self._pages

    @pages.setter
    def pages(self, pages):
        """Sets the pages of this UserMobileInfo.


        :param pages: The pages of this UserMobileInfo.  # noqa: E501
        :type: JsonNode
        """

        self._pages = pages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserMobileInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserMobileInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
